

log using FinalResults.log, replace

clear
set mem 400m
set more off

* get data
use panel17



**%%%%%%%%% do not use noisy french loans data before 1895
replace loans1 = . if year<=1895 & iso=="FRA"

* omit 2009
drop if year==2009

* make ccodes, sort, tsset
egen ccode = group(iso)
tab iso, gen(ccode)
sort ccode year
 xtset ccode year

* make some series
* loans1 = loans to private sector
gen loansgdp = loans1/gdp
gen credgdp = bassets2/gdp
gen moneygdp = money/gdp
gen loansmoney = loans1/money
gen credmoney= bassets2/money

gen lloansmoney = log(loansmoney)
gen lcredmoney = log(credmoney)

gen dlloansmoney=d.lloansmoney 
gen dlcredmoney=d.lcredmoney 


gen credimp = d.loans1/gdp

gen lev = loans1/money
gen dlev = d.lev
gen lm = log(money)
gen dlm = d.lm
gen dmgdp = d.money/gdp

gen lnm = log(narrowm)
gen dlnm = d.lnm

gen lloans = log(loans1)
gen dlloans = d.lloans
gen lassets = log(bassets2)
gen dlassets = d.lassets


sort ccode year
 xtset ccode year 


*********

* more series

gen lcred = log(bassets2)
gen dlcred = d.lcred

gen lcredm = log(bassets2/money)
gen lloansm = log(loans1/money)


gen pre45 = 1 if year<=1945
replace pre45 = 0 if year>1945

gen post45 = 1 if year>1945
replace post45 = 0 if year<=1945

gen era = "PostWW2" if year>1945
replace era = "PreWW2" if year<=1945

gen era2 = "1_PostWW2" if year>1945
replace era2 = "0_PreWW2" if year<=1945

gen gtdep = 0
replace gtdep = 1 if year>1929 & year<1940

gen syear = year-1800
*graph bar lloansm lcredm , over(syear)

gen decade = year-ceil(year/10)*10
replace decade = . if decade~=0
replace decade = year if decade~=.

gen quinq = year-ceil(year/5)*5
replace quinq = . if quinq ~=0
replace quinq = year if quinq ~=.

gen yearx = string(year)
replace yearx = "" if quinq==.





gen sample = . if crisisST~=.
replace sample=0 if crisisST[_n]>=1 & crisisST[_n-1]==0
replace sample=1 if sample[_n-1]==0
replace sample=2 if sample[_n-1]==1
replace sample=3 if sample[_n-1]==2
replace sample=4 if sample[_n-1]==3
replace sample=5 if sample[_n-1]==4
replace sample = -1 if sample==.

* -1 is "normal"

*********

* more series

sort iso year
tsset ccode year, yearly


** wars

gen ww1 = 1 if year>=1914 & year<=1919
gen ww2 = 1 if year>=1939 & year<=1947
replace ww1 = 0 if ww1~=1
replace ww2 = 0 if ww2~=1

gen war=1 if ww1==1|ww2==1
replace war=0 if war~=1



gen sample2 = sample if ww1==0 & ww2==0
gen sample2s = string(sample2)
replace sample2s = " Normal " if sample2==-1
replace sample2s = "0" if sample2==0

gen securities = bassets2-loans1
gen cap1 = sec/bassets2*100
gen cap2 = govass/bassets2*100

gen lsec = log(securities)
gen lgovass = log(govass)
gen dlsec = d.lsec
gen dlgovass = d.lgovass
gen lgovbal = log(govass/bassets2)
gen lsecbal = log(sec/bassets2)

gen dlsecbal = dlsec-dlassets
gen dlgovbal = dlgovass-dlassets


qui xi: xtreg lloansm i.year, fe
predict lloansmz
bysort year: egen lloansmx = mean(lloansmz)
qui xi: xtreg lcredm i.year, fe
predict lcredmz
bysort year: egen lcredmx= mean(lcredmz)
sort iso year


qui xi: xtreg lsecbal i.year, fe
predict lsecbalz
bysort year: egen lsecbalx = mean(lsecbalz)
qui xi: xtreg lgovbal i.year if year>=1952, fe
predict lgovbalz if year>=1952
bysort year: egen lgovbalx= mean(lgovbalz) if year>=1952
sort iso year

gen lcredmus = lcredm if iso=="USA"

*graph bar lloansmz lcredmz , over(syear)
*graph bar lcredmus lcredmz , over(syear)
*graph bar loansgdp credgdp moneygdp , over(syear)

qui xi: xtreg loansgdp i.year, fe
predict loansgdpz
bysort year: egen loansgdpx = mean(loansgdpz)
qui xi: xtreg credgdp i.year, fe
predict credgdpz
bysort year: egen credgdpx= mean(credgdpz)
sort iso year
qui xi: xtreg moneygdp i.year, fe
predict moneygdpz
bysort year: egen moneygdpx= mean(moneygdpz)
sort iso year


sort iso year
tsset ccode year, yearly


gen lrgdp = log(rgdp)
gen dlrgdp = d.lrgdp
gen diy = d.iy

gen lpc = log(cpi)
gen dlpc = d.lpc

gen lcredr = lcred-lpc
gen lloansr = lloans-lpc
gen lmr= lm-lpc
gen lnarrowm = log(narrowm)
gen linvr  = ln(iy) + lrgdp
gen lmmult = lm-lnm
gen dlinvr = d.linvr


*** label main vars

label var loansgdpx "Bank Loans/GDP"
label var credgdpx  "Bank Assets/GDP"
label var moneygdpx "Broad Money/GDP"

label var loansgdp "Bank Loans/GDP"
label var credgdp  "Bank Assets/GDP"
label var moneygdp "Broad Money/GDP"

label var loansgdp "Bank Loans/Money"
label var credgdp  "Bank Assets/Money"

label var lloansmx "log(Bank Loans/Broad Money)"
label var lcredmx  "log(Bank Assets/Broad Money)"

label var lloansm "log(Bank Loans/Broad Money)"
label var lcredm  "log(Bank Assets/Broad Money)"

label var dlrgdp  "D log Real GDP"
label var dlpc  "D log CPI"
label var dlnm  "D log Narrow Money"
label var dlm  "D log Money"
label var dlloans  "D log Loans"
label var dlcred  "D log Assets"
label var dlloansmoney  "D log Loans/Money"
label var dlcredmoney  "D log Assets/Money"

label var loansmoney "Loans/Money"
label var credmoney "Assets/Money"



*** APPX Table :  display crisis dates (check)

list iso year if crisisST==1


******************* Tables 1 & 2 ************************

sort iso year
tsset ccode year, yearly


*** Table 1 - summary stats (exclude wars)
sum loansgdp credgdp moneygdp loansmoney credmoney d.lrgdp d.lnm d.lm d.lpc d.lloans d.lcred d.lloansmoney d.lcredmoney if pre45==1 & war==0
sum loansgdp credgdp moneygdp loansmoney credmoney d.lrgdp d.lnm d.lm d.lpc d.lloans d.lcred d.lloansmoney d.lcredmoney if post45==1 & war==0

preserve
drop if war==1
sort era2
by era2: eststo: quietly estpost ///
	summarize loansgdp credgdp moneygdp loansmoney credmoney ///
		dlrgdp dlpc dlnm dlm  dlloans dlcred dlloansmoney dlcredmoney

esttab using FinalTable01.tex, cells("count mean(fmt(4)) sd(fmt(4))") label page replace
eststo clear
restore


*** Table 2 - cumulative effects years 0-5 (exclude wars)

preserve
drop if war==1

foreach var of varlist d.lm d.lnm d.lloans d.lcred d.lrgdp d.linvr d.lpc {
qui xi: xtreg `var' i.sample2 if pre45==1 & war==0, fe
lincom _Isample2_2+_Isample2_3+_Isample2_4+_Isample2_5+_Isample2_6+_Isample2_7
}

foreach var of varlist d.lm d.lnm d.lloans d.lcred d.lrgdp d.linvr d.lpc {
qui xi: xtreg `var' i.sample2 if pre45==1 & war==0 & year<1929, fe
lincom _Isample2_2+_Isample2_3+_Isample2_4+_Isample2_5+_Isample2_6+_Isample2_7
}

foreach var of varlist d.lm d.lnm d.lloans d.lcred d.lrgdp d.linvr d.lpc {
qui xi: xtreg `var' i.sample2 if post45==1 & war==0, fe
lincom _Isample2_2+_Isample2_3+_Isample2_4+_Isample2_5+_Isample2_6+_Isample2_7
}

restore


******************* Figures 1-4 and Appendix ************************

*** Figures 1-2 --- basic trends

* keep war years in for now
* year effects (AND OMIT 2008)

scatter loansgdpx credgdpx moneygdpx year if year<2008, ///
	saving(FinalFigure01,replace) title("Figure 1. Aggregates Relative to GDP (Year Effects)")  scale(.8)

scatter loansgdpx credgdpx moneygdpx year if year<2008, scheme(s1mono)
graph export FinalFigure01.pdf, replace

scatter lloansmx lcredmx year if year<2008, ///
	saving(FinalFigure02,replace) title("Figure 2. Aggregates Relative to Broad Money (Year Effects)") scale(.8)

scatter lloansmx lcredmx year if year<2008, scheme(s1mono)
graph export FinalFigure02.pdf, replace

*** Figure 3 --- compare across countries

label var lloansm "log(Loans/Broad Money)"
label var lcredm "log(Assets/Broad Money)"
scatter lloansm lcredm year if decade~=. & year>=1870,  ///
	 by(iso, title("Figure 3. Credit Relative to Broad Money by Country") subtitle("(decades since 1870)")) ysize(6) scale(.8) m(O S)
graph display, scale(.6)
graph save FinalFigure03, replace

scatter lloansm lcredm year if decade~=. & year>=1870,  ///
	 by(iso) m(O S) scheme(s1mono)
graph export FinalFigure03.pdf, replace


*** Figure 4 --- post crisis bar charts

label var dlcred "D log(Bank Assets)"
label var dlloans "D log(Bank Loans)"
label var dlm "D log(Broad Money)"
label var dlrgdp "D log(Real GDP)"
label var dlinvr "D log(Real Investment)"
label var dlnm "D log(Narrow Money)"
label var dlpc "D log(CPI)"

graph bar dlcred dlloans dlm  ///
	if sample2~=. , over(sample2s) over(era,sort(post45))  ///
	title(Figure 4a. Aggregates) saving(FinalFigure04,replace) scale(.8) ///
	legend(lab(1 "D log(Bank Assets)") lab(2 "D log(Bank Loans)") lab(3 "D log(Broad Money)"))
graph bar dlcred dlloans dlm  ///
	if sample2~=. , over(sample2s) over(era,sort(post45)) ///
	legend(lab(1 "D log(Bank Assets)") lab(2 "D log(Bank Loans)") lab(3 "D log(Broad Money)")) ///
	scheme(s1mono)
graph export FinalFigure04.pdf, replace


graph bar dlrgdp dlinvr ///
	if sample2~=. , over(sample2s) over(era,sort(post45))  ///
	title(Figure 4b. Real Variables) saving(FinalFigure05,replace) scale(.8) ///
	legend(lab(1 "D log(Real GDP)") lab(2 "D log(Real Investment)"))
graph bar dlrgdp dlinvr ///
	if sample2~=. , over(sample2s) over(era,sort(post45))  ///
	legend(lab(1 "D log(Real GDP)") lab(2 "D log(Real Investment)")) ///
	scheme(s1mono)
graph export FinalFigure05.pdf, replace





graph bar dlm dlnm dlpc  ///
	if sample2~=. , over(sample2s) over(era,sort(post45))  ///
	title(Figure 4c. Money and Inflation) saving(FinalFigure06,replace) scale(.8)  ///
	legend(lab(1 "D log(Broad Money)") lab(2 "D log(Narrow Money)") lab(3 "D log((CPI))"))
graph bar dlm dlnm dlpc  ///
	if sample2~=. , over(sample2s) over(era,sort(post45))  ///
	legend(lab(1 "D log(Broad Money)") lab(2 "D log(Narrow Money)") lab(3 "D log((CPI))")) ///
	scheme(s1mono)
graph export FinalFigure06.pdf, replace


*** Appendix Figure ---  raw data

scatter credgdp loansgdp moneygdp year, ///
	by(iso,title("Appendix Figure 1. Raw data")) scale(.8) ysize(7)
	graph display, scale(.6)
	graph save FinalFigureA1, replace
scatter credgdp loansgdp moneygdp year, ///
	by(iso) scheme(s1mono)
graph export FinalFigureA1.pdf, replace


*******************************************************************************
* drop wars

sum year if ww1==1
sum year if ww2==1

drop if ww1==1 | ww2==1

*******************************************************************************

**** Table 3 --  

gen dlloansr = dlloans - dlpc

tssmooth ma dlloansr10=dlloansr, window(10 0 0)
tssmooth ma dlloansr5=dlloansr, window(5 0 0)

drop dlloansr* 
gen dlloansr = dlloans - dlpc
gen dlnmr = dlnm - dlpc
gen dlmr = dlm - dlpc


sort ccode year
 xtset ccode year 

 
* linear probabilty no FE
 reg crisisST l(1/5).dlloansr 
 
 testparm l(1/5).dlloansr
	local F = r(F)
 	local pF = r(p)
 predict temp, xb
 roctab crisisST temp
  	local area1 = r(area)
 	local seroc = r(se)
lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
	local lagsum = r(estimate)
	local lagsumse = r(se)
	ksmirnov temp, by(crisisST) exact
 	outreg2 l(1/5).dlloansr ///
 	using FinalTable03, tex nocons e(N r2 F ll) ///
 	addstat(Floans, `F', pF, `pF', AUROC, `area1', ///
 	seroc, `seroc', lagsum, `lagsum', lagsumse, `lagsumse')  replace 

 drop temp

 
* linear probabilty CFE
reg crisisST l(1/5).dlloansr ccode* 
 
 testparm ccode*
 testparm l(1/5).dlloansr
	local F = r(F)
 	local pF = r(p)
 predict temp, xb
 roctab crisisST temp
  	local area1 = r(area)
 	local seroc = r(se)
lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
	local lagsum = r(estimate)
	local lagsumse = r(se)
 	ksmirnov temp, by(crisisST) exact
 	outreg2 l(1/5).dlloansr ///
 	using FinalTable03, tex nocons e(N r2 F ll) ///
 	addstat(Floans, `F', pF, `pF', AUROC, `area1', ///
 	seroc, `seroc', lagsum, `lagsum', lagsumse, `lagsumse')  
 drop temp

 
* linear probabilty CFE & TFE
 xi: xtreg crisisST l(1/5).dlloansr i.year, fe 
 
 testparm _Iyear*
 
 testparm l(1/5).dlloansr
	local F = r(F)
 	local pF = r(p)
 predict temp, xb
 roctab crisisST temp
  	local area1 = r(area)
 	local seroc = r(se)
lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
	local lagsum = r(estimate)
	local lagsumse = r(se)
 	ksmirnov temp, by(crisisST) exact
 	outreg2 l(1/5).dlloansr ///
 	using FinalTable03, tex nocons e(N r2 F ll) ///
 	addstat(Floans, `F', pF, `pF', AUROC, `area1', ///
 	seroc, `seroc', lagsum, `lagsum', lagsumse, `lagsumse')  
 drop temp
 
* pooled logit no FE
 logit crisisST l(1/5).dlloansr  ,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 predict temp , xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 l(1/5).dlloansr using FinalTable03, ///
			tex nocons ///
			addstat( ///
  			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  

 	ksmirnov temp, by(crisisST) exact
 drop temp
 
 
* panel logit CFE = baseline
logit crisisST l(1/5).dlloansr ccode*  ,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 predict temp , xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 l(1/5).dlloansr using FinalTable03, ///
			tex nocons ///
			addstat( ///
			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			chicountry, `ccountry', pcountry, `pcountry', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  

 	ksmirnov temp, by(crisisST) exact
 	
gen phat = temp
drop temp

gen ind = sign(phat)
tab ind crisisST
 

*******************************************************************************
* Figure 7 --  
* baseline ROC

roctab crisisST phat, graph summary scale(.8)  ///
 	title("Figure 5. Receiver Operating Characteristic Curve, Baseline Model")
graph save crisisrocbaseline, replace
roctab crisisST phat, graph summary scheme(s1mono) 
graph export FinalFigure07.pdf, replace



*******************************************************************************
* Text discussion: in versus out of sample ?

 logit crisisST ccode* l(1/5).dlloansr ,  vce(robust)
 predict tempin, xb
 replace tempin = . if year<1984

gen tempout = .
forvalues yr = 1984/2008  {
qui logit crisisST ccode* l(1/5).dlloansr  if year< `yr'
 predict temp, xb
 replace tempout = temp if year==`yr'
 drop temp
 }
 
 roctab crisisST tempin 
 roctab crisisST tempout
 
 roccomp crisisST tempin tempout
 
gen in_sample = tempin
gen out_of_sample = tempout

* roc for in and out of sample
 roccomp crisisST in_sample out_of_sample, graph scale(.8)
 graph save crisisrocinandout, replace

sum year if tempin~=. & tempout~=.





*******************************************************************************
* Table 4 --  
* what is the best signal, narrow money, broad money or credit (real growth rate)?


* baseline first
 
 logit crisisST l(1/5).dlloansr ccode* ,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 predict temp , xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 using FinalTable04, ///
			tex nocons ///
			addstat( ///
			mfx1, `mfx1', ///
			mfx2, `mfx2', ///
			mfx3, `mfx3', ///
			mfx4, `mfx4', ///
			mfx5, `mfx5', ///
			mfxsum, `mfxsum', ///
			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			chicountry, `ccountry', pcountry, `pcountry', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  replace

 drop temp


* broad money
 logit crisisST l(1/5).dlmr ccode*,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlmr
			local cloans = r(chi2)
			local ploans = r(p)
		 predict temp , xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlmr+L2.dlmr+L3.dlmr+L4.dlmr+L5.dlmr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 using FinalTable04, ///
			tex nocons ///
			addstat( ///
			mfx1, `mfx1', ///
			mfx2, `mfx2', ///
			mfx3, `mfx3', ///
			mfx4, `mfx4', ///
			mfx5, `mfx5', ///
			mfxsum, `mfxsum', ///
			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			chicountry, `ccountry', pcountry, `pcountry', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  append

 drop temp
 

* narrow money 
 logit crisisST l(1/5).dlnmr ccode* ,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlnmr
			local cloans = r(chi2)
			local ploans = r(p)
		 predict temp , xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlnmr+L2.dlnmr+L3.dlnmr+L4.dlnmr+L5.dlnmr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 using FinalTable04, ///
			tex nocons ///
			addstat( ///
			mfx1, `mfx1', ///
			mfx2, `mfx2', ///
			mfx3, `mfx3', ///
			mfx4, `mfx4', ///
			mfx5, `mfx5', ///
			mfxsum, `mfxsum', ///
			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			chicountry, `ccountry', pcountry, `pcountry', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  append
 drop temp
 

*   normalize loans by gdp or broadm (lev)
  
drop dlloansr* phat ind
gen lloansgdp = log(loansgdp)
gen dlloansr = d.lloansgdp


sort ccode year
 xtset ccode year

 logit crisisST l(1/5).dlloansr ccode* ,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 predict temp , xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 using FinalTable04, ///
			tex nocons ///
			addstat( ///
			mfx1, `mfx1', ///
			mfx2, `mfx2', ///
			mfx3, `mfx3', ///
			mfx4, `mfx4', ///
			mfx5, `mfx5', ///
			mfxsum, `mfxsum', ///
			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			chicountry, `ccountry', pcountry, `pcountry', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  append
 drop temp
 
drop dlloansr* 
gen dlloansr = d.lloansm


 logit crisisST l(1/5).dlloansr ccode*,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 predict temp , xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 using FinalTable04, ///
			tex nocons ///
			addstat( ///
			mfx1, `mfx1', ///
			mfx2, `mfx2', ///
			mfx3, `mfx3', ///
			mfx4, `mfx4', ///
			mfx5, `mfx5', ///
			mfxsum, `mfxsum', ///
			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			chicountry, `ccountry', pcountry, `pcountry', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  append
 drop temp
 




 *******************************************************************************
 * Table 5 -- now repeat preferred specs pre and post ww2
 
drop dlloansr* 
gen dlloansr = dlloans - dlpc


 logit crisisST l(1/5).dlloansr ccode* if pre45==1 ,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 predict temp if pre45==1, xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 using FinalTable05, ///
			tex nocons ///
			addstat( ///
			mfx1, `mfx1', ///
			mfx2, `mfx2', ///
			mfx3, `mfx3', ///
			mfx4, `mfx4', ///
			mfx5, `mfx5', ///
			mfxsum, `mfxsum', ///
			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			chicountry, `ccountry', pcountry, `pcountry', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  replace

 gen tempcpre = temp
 drop temp

 
 logit crisisST l(1/5).dlloansr ccode* if post45==1 ,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 predict temp if post45==1, xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 using FinalTable05, ///
			tex nocons ///
			addstat( ///
			mfx1, `mfx1', ///
			mfx2, `mfx2', ///
			mfx3, `mfx3', ///
			mfx4, `mfx4', ///
			mfx5, `mfx5', ///
			mfxsum, `mfxsum', ///
			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			chicountry, `ccountry', pcountry, `pcountry', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  append
 
 gen tempcpost = temp
 drop temp
 

 drop dlloansr* 
gen dlloansr = dlmr

 logit crisisST l(1/5).dlloansr ccode* if pre45==1 ,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 predict temp if pre45==1, xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 using FinalTable05, ///
			tex nocons ///
			addstat( ///
			mfx1, `mfx1', ///
			mfx2, `mfx2', ///
			mfx3, `mfx3', ///
			mfx4, `mfx4', ///
			mfx5, `mfx5', ///
			mfxsum, `mfxsum', ///
			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			chicountry, `ccountry', pcountry, `pcountry', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  append
 
 gen tempmpre = temp
 drop temp


 logit crisisST l(1/5).dlloansr ccode* if post45==1 ,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 predict temp if post45==1, xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 using FinalTable05, ///
			tex nocons ///
			addstat( ///
			mfx1, `mfx1', ///
			mfx2, `mfx2', ///
			mfx3, `mfx3', ///
			mfx4, `mfx4', ///
			mfx5, `mfx5', ///
			mfxsum, `mfxsum', ///
			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			chicountry, `ccountry', pcountry, `pcountry', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  append
 
gen tempmpost = temp
drop temp
 
 
 
* ROC comparisons for these models on common samples

roccomp crisisST tempcpre tempmpre
roccomp crisisST tempcpre tempmpre, gr
graph save FinalFigure08a, replace
graph display, scheme(s1mono)
graph export FinalFigure08a.pdf, replace


roccomp crisisST tempcpost tempmpost
roccomp crisisST tempcpost tempmpost, gr
graph save FinalFigure08b, replace
graph display, scheme(s1mono)
graph export FinalFigure08b.pdf, replace

ksmirnov tempcpre, by(crisisST) exact
ksmirnov tempmpre, by(crisisST) exact
 
ksmirnov tempcpost, by(crisisST) exact
ksmirnov tempmpost, by(crisisST) exact




*******************************************************************************
* Table 6 --  do other signals matter

***** is output any help?

drop dlloansr* 
gen dlloansr = dlloans - dlpc

gen xxx = dlrgdp
logit crisisST l(1/5).dlloansr l(1/5).xxx ccode* ,  vce(robust)
 		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 testparm l(1/5).xxx
			local cx = r(chi2)
 			local px = r(p)
		 predict temp if pre45==1, xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 using FinalTable06, ///
			tex nocons ///
			addstat( ///
			mfx1, `mfx1', ///
			mfx2, `mfx2', ///
			mfx3, `mfx3', ///
			mfx4, `mfx4', ///
			mfx5, `mfx5', ///
			mfxsum, `mfxsum', ///
			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			chix, `cx', px, `px', ///
			chicountry, `ccountry', pcountry, `pcountry', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  replace

	 	ksmirnov temp, by(crisisST) exact
 		drop temp xxx
 
***** is inflation any help?

drop dlloansr* 
gen dlloansr = dlloans - dlpc

gen xxx = dlpc
logit crisisST l(1/5).dlloansr l(1/5).xxx ccode* ,  vce(robust)
 		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 testparm l(1/5).xxx
			local cx = r(chi2)
 			local px = r(p)
		 predict temp if pre45==1, xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 using FinalTable06, ///
			tex nocons ///
			addstat( ///
			mfx1, `mfx1', ///
			mfx2, `mfx2', ///
			mfx3, `mfx3', ///
			mfx4, `mfx4', ///
			mfx5, `mfx5', ///
			mfxsum, `mfxsum', ///
			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			chix, `cx', px, `px', ///
			chicountry, `ccountry', pcountry, `pcountry', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  append

	 	ksmirnov temp, by(crisisST) exact
 		drop temp xxx
 
***** is stir any help?

drop dlloansr* 
gen dlloansr = dlloans - dlpc

gen xxx = stir
logit crisisST l(1/5).dlloansr l(1/5).xxx ccode* ,  vce(robust)
 		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 testparm l(1/5).xxx
			local cx = r(chi2)
 			local px = r(p)
		 predict temp if pre45==1, xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 using FinalTable06, ///
			tex nocons ///
			addstat( ///
			mfx1, `mfx1', ///
			mfx2, `mfx2', ///
			mfx3, `mfx3', ///
			mfx4, `mfx4', ///
			mfx5, `mfx5', ///
			mfxsum, `mfxsum', ///
			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			chix, `cx', px, `px', ///
			chicountry, `ccountry', pcountry, `pcountry', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  append

	 	ksmirnov temp, by(crisisST) exact
 		drop temp xxx
 

***** is real stir any help?

drop dlloansr* 
gen dlloansr = dlloans - dlpc

gen xxx = stir - d.lpc

logit crisisST l(1/5).dlloansr l(1/5).xxx ccode* ,  vce(robust)
 		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 testparm l(1/5).xxx
			local cx = r(chi2)
 			local px = r(p)
		 predict temp if pre45==1, xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 using FinalTable06, ///
			tex nocons ///
			addstat( ///
			mfx1, `mfx1', ///
			mfx2, `mfx2', ///
			mfx3, `mfx3', ///
			mfx4, `mfx4', ///
			mfx5, `mfx5', ///
			mfxsum, `mfxsum', ///
			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			chix, `cx', px, `px', ///
			chicountry, `ccountry', pcountry, `pcountry', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  append

	 	ksmirnov temp, by(crisisST) exact
 		drop temp xxx
 

***** is investment any help?

drop dlloansr* 
gen dlloansr = dlloans - dlpc

gen xxx = diy

logit crisisST l(1/5).dlloansr l(1/5).xxx ccode* ,  vce(robust)
 		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 testparm l(1/5).xxx
			local cx = r(chi2)
 			local px = r(p)
		 predict temp if pre45==1, xb
		 roctab crisisST temp
			local area1 = r(area)
			local seroc = r(se)
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
			ksmirnov temp, by(crisisST) exact
		outreg2 using FinalTable06, ///
			tex nocons ///
			addstat( ///
			mfx1, `mfx1', ///
			mfx2, `mfx2', ///
			mfx3, `mfx3', ///
			mfx4, `mfx4', ///
			mfx5, `mfx5', ///
			mfxsum, `mfxsum', ///
			nobs, `nobs', ///
			Lagsum, `lagsum', lagsumse, `lagsumse', ///
			chiloans, `cloans', ploans, `ploans', ///
			chix, `cx', px, `px', ///
			chicountry, `ccountry', pcountry, `pcountry', ///
			pseudo-r2, `pseud', ///
			pseddo-l, `ll', ///
			chi2, `chi2logit', ///
			plogit, `plogit', ///
			AUROC, `area1', seroc, `seroc' ///
			)  append

	 	ksmirnov temp, by(crisisST) exact
 		drop temp xxx


 *******************************************************************************
drop if war==1

 * Table 7 -- now repeat preferred specs with asset prices
 
drop dlloansr* 
gen dlloansr = dlloans - dlpc
gen lstkp = log(stocks)
gen dlstkp = d.lstkp
gen dlrstkp = dlstkp - dlpc

tssmooth ma dlloansr10=dlloansr, window(10 0 0)
tssmooth ma dlloansr5=dlloansr, window(5 0 0)


tssmooth ma dlstkp5=dlstkp, window(5 0 0)
tssmooth ma dlrstkp5=dlrstkp, window(5 0 0)

tssmooth ma dlrinv5=dlinvr, window(5 0 0)


*** set sample
logit crisisST l(1/5).dlloansr l(1/5).dlrstkp loansgdp ccode* ,  vce(robust)
gen stksmpl = e(sample)


**loans and nominal stock prices
logit crisisST l(1/5).dlloansr l(1/5).dlstkp ccode* if stksmpl==1,  vce(robust)

		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 testparm l(1/5).dlstkp
			local cx = r(chi2)
 			local px = r(p)
       	 predict temp , xb
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
		lincom L.dlstkp+L2.dlstkp+L3.dlstkp+L4.dlstkp+L5.dlstkp
	 outreg2 using FinalTable07, tex nocons addstat( mfx1, `mfx1', mfx2, `mfx2', mfx3, `mfx3', mfx4, `mfx4', mfx5, `mfx5', mfxsum, `mfxsum', nobs, `nobs', Lagsum, `lagsum', lagsumse, `lagsumse', chiloans, `cloans', ploans, `ploans', chix, `cx', px, `px', chicountry, `ccountry', pcountry, `pcountry', pseudo-r2, `pseud', pseudo-l, `ll', chi2, `chi2logit', plogit, `plogit')  replace
			roctab crisisST temp if stksmpl==1
			local area1 = r(area)
			local seroc = r(se)
			ksmirnov temp, by(crisisST) exact
		 outreg2 using FinalTable07, tex nocons append addstat( AUROC, `area1', seroc, `seroc')  

 gen temp1 = temp
 drop temp

**loans and real stock prices
logit crisisST l(1/5).dlloansr l(1/5).dlrstkp ccode*,  vce(robust)

		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 testparm l(1/5).dlrstkp
			local cx = r(chi2)
 			local px = r(p)
       	 predict temp , xb
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
		lincom L.dlrstkp+L2.dlrstkp+L3.dlrstkp+L4.dlrstkp+L5.dlrstkp
	 outreg2 using FinalTable07, tex nocons addstat( mfx1, `mfx1', mfx2, `mfx2', mfx3, `mfx3', mfx4, `mfx4', mfx5, `mfx5', mfxsum, `mfxsum', nobs, `nobs', Lagsum, `lagsum', lagsumse, `lagsumse', chiloans, `cloans', ploans, `ploans', chix, `cx', px, `px', chicountry, `ccountry', pcountry, `pcountry', pseudo-r2, `pseud', pseudo-l, `ll', chi2, `chi2logit', plogit, `plogit')  append
			roctab crisisST temp if stksmpl==1
			local area1 = r(area)
			local seroc = r(se)
			ksmirnov temp, by(crisisST) exact
		 outreg2 using FinalTable07, tex nocons append addstat( AUROC, `area1', seroc, `seroc')  

 gen temp2 = temp
 drop temp

***loans and credit levels
qui logit crisisST l(1/5).dlloansr loansgdp ccode*,  vce(robust)


		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 predict temp, xb
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
		 outreg2 using FinalTable07, tex nocons addstat( mfx1, `mfx1', mfx2, `mfx2', mfx3, `mfx3', mfx4, `mfx4', mfx5, `mfx5', mfxsum, `mfxsum', nobs, `nobs', Lagsum, `lagsum', lagsumse, `lagsumse', chiloans, `cloans', ploans, `ploans', chicountry, `ccountry', pcountry, `pcountry', pseudo-r2, `pseud', pseudo-l, `ll', chi2, `chi2logit', plogit, `plogit')  append
			roctab crisisST temp if stksmpl==1
			local area1 = r(area)
			local seroc = r(se)
			ksmirnov temp, by(crisisST) exact
		 outreg2 using FinalTable07, tex nocons append addstat( AUROC, `area1', seroc, `seroc')  

 gen temp3 = temp
 drop temp



***loans, stocks, levels
logit crisisST l(1/5).dlloansr l(1/5).dlrstkp loansgdp ccode*,  vce(robust)
		  local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
			local mfx5 = A[1,5]
			local mfxsum = A[1,1]+A[1,2]+A[1,3]+A[1,4]+A[1,5]
			
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		 testparm l(1/5).dlloansr
			local cloans = r(chi2)
			local ploans = r(p)
		 testparm l(1/5).dlrstkp
			local cx = r(chi2)
 			local px = r(p)
       	 predict temp , xb
		lincom L.dlloansr+L2.dlloansr+L3.dlloansr+L4.dlloansr+L5.dlloansr
			local lagsum = r(estimate)
			local lagsumse = r(se)
		lincom L.dlrstkp+L2.dlrstkp+L3.dlrstkp+L4.dlrstkp+L5.dlrstkp
	 outreg2 using FinalTable07, tex nocons addstat( mfx1, `mfx1', mfx2, `mfx2', mfx3, `mfx3', mfx4, `mfx4', mfx5, `mfx5', mfxsum, `mfxsum', nobs, `nobs', Lagsum, `lagsum', lagsumse, `lagsumse', chiloans, `cloans', ploans, `ploans', chix, `cx', px, `px', chicountry, `ccountry', pcountry, `pcountry', pseudo-r2, `pseud', pseudo-l, `ll', chi2, `chi2logit', plogit, `plogit')  append
			roctab crisisST temp if stksmpl==1
			local area1 = r(area)
			local seroc = r(se)
			ksmirnov temp, by(crisisST) exact
		 outreg2 using FinalTable07, tex nocons append addstat( AUROC, `area1', seroc, `seroc')  


 gen temp4 = temp
 drop temp


* ROC comparisons for these models on common samples

roccomp crisisST temp1 temp2
*roccomp crisisST temp1 temp2, gr

roccomp crisisST temp1 temp3
*roccomp crisisST temp1 temp3, gr

roccomp crisisST temp2 temp3
*roccomp crisisST temp2 temp3, gr

roccomp crisisST temp3 temp4
*roccomp crisisST temp3 temp4, gr


 *******************************************************************************
 * Table 8 -- preferred specs with ma5 interactions
 
gen dll5=dlloansr5
gen dls5=dlrstkp5

egen dls5m= mean(dls5)
gen dll5dls5=dll5*(dls5-dls5m)

egen loansgdpm= mean(loansgdp)
gen dll5loans=dll5*(loansgdp-loansgdpm)
gen dls5loans=dls5*(loansgdp-loansgdpm)



drop sample2

* set sample
qui logit crisisST dll5 dls5 dll5dls5 loansgdp dll5loans ccode* ,  vce(robust)
gen sample2=e(sample)


***baseline
logit crisisST dll5 ccode* if sample2,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			matrix list A
			local mfx1 = A[1,1]
		testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		predict temp, xb
		 outreg2 using FinalTable08, tex nocons addstat( mfx1, `mfx1', nobs, `nobs', chicountry, `ccountry', pcountry, `pcountry', pseudo-r2, `pseud', pseudo-l, `ll', chi2, `chi2logit', plogit, `plogit')  replace
			roctab crisisST temp if sample2
			local area1 = r(area)
			local seroc = r(se)
			ksmirnov temp, by(crisisST) exact
		 outreg2 using FinalTable08, tex nocons append addstat( AUROC, `area1', seroc, `seroc')  

 gen temp10 = temp
 drop temp


***add stocks
logit crisisST dll5 dls5 ccode* if sample2,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			matrix list A
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		predict temp, xb
		outreg2 using FinalTable08, tex nocons addstat( mfx1, `mfx1', mfx2, `mfx2', nobs, `nobs', chicountry, `ccountry', pcountry, `pcountry', pseudo-r2, `pseud', pseudo-l, `ll', chi2, `chi2logit', plogit, `plogit')  append
			roctab crisisST temp if sample2
			local area1 = r(area)
			local seroc = r(se)
			ksmirnov temp, by(crisisST) exact
		 outreg2 using FinalTable08, tex nocons append addstat( AUROC, `area1', seroc, `seroc')  

 gen temp11 = temp
 drop temp

**interact loans and stocks
logit crisisST dll5 dls5 dll5dls5 ccode* if sample2,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			matrix list A
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		predict temp, xb
		 outreg2 using FinalTable08, tex nocons addstat( mfx1, `mfx1', mfx2, `mfx2', mfx3, `mfx3', nobs, `nobs', chicountry, `ccountry', pcountry, `pcountry', pseudo-r2, `pseud', pseudo-l, `ll', chi2, `chi2logit', plogit, `plogit')  append
			roctab crisisST temp if sample2
			local area1 = r(area)
			local seroc = r(se)
			ksmirnov temp, by(crisisST) exact
		 outreg2 using FinalTable08, tex nocons append addstat( AUROC, `area1', seroc, `seroc')  
 
gen temp12 = temp
drop temp


**add levels
logit crisisST dll5 loansgdp ccode*,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			matrix list A
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		predict temp, xb
		 outreg2 using FinalTable08, tex nocons addstat( mfx1, `mfx1', mfx2, `mfx2', nobs, `nobs', chicountry, `ccountry', pcountry, `pcountry', pseudo-r2, `pseud', pseudo-l, `ll', chi2, `chi2logit', plogit, `plogit')  append
			roctab crisisST temp if sample2
			local area1 = r(area)
			local seroc = r(se)
			ksmirnov temp, by(crisisST) exact
		 outreg2 using FinalTable08, tex nocons append addstat( AUROC, `area1', seroc, `seroc')  

 gen temp13 = temp
 drop temp

 
**interact loans and levels
logit crisisST dll5 loansgdp dll5loans ccode* ,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			matrix list A
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		predict temp, xb
		 outreg2 using FinalTable08, tex nocons addstat( mfx1, `mfx1', mfx2, `mfx2', mfx3, `mfx3', nobs, `nobs', chicountry, `ccountry', pcountry, `pcountry', pseudo-r2, `pseud', pseudo-l, `ll', chi2, `chi2logit', plogit, `plogit')  append
			roctab crisisST temp if sample2
			local area1 = r(area)
			local seroc = r(se)
			ksmirnov temp, by(crisisST) exact
		 outreg2 using FinalTable08, tex nocons append addstat( AUROC, `area1', seroc, `seroc')  

 gen temp14 = temp
 drop temp

**credit plus interaction loans and stocks

logit crisisST dll5 loansgdp dls5 dls5loans ccode* ,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		mfx 
			matrix A= e(Xmfx_dydx)
			matrix list A
			local mfx1 = A[1,1]
			local mfx2 = A[1,2]
			local mfx3 = A[1,3]
			local mfx4 = A[1,4]
		 testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
		predict temp, xb
		 outreg2 using FinalTable08, tex nocons addstat( mfx1, `mfx1', mfx2, `mfx2', mfx3, `mfx3', mfx4, `mfx4',  nobs, `nobs', chicountry, `ccountry', pcountry, `pcountry', pseudo-r2, `pseud', pseudo-l, `ll', chi2, `chi2logit', plogit, `plogit')  append
			roctab crisisST temp if sample2
			local area1 = r(area)
			local seroc = r(se)
			ksmirnov temp, by(crisisST) exact
		 outreg2 using FinalTable08, tex nocons append addstat( AUROC, `area1', seroc, `seroc')  

 gen temp15 = temp
 drop temp


roccomp crisisST temp11 temp12
*roccomp crisisST temp11 temp12, gr

roccomp crisisST temp11 temp13
*roccomp crisisST temp11 temp13, gr

roccomp crisisST temp13 temp14
*roccomp crisisST temp13 temp14, gr

roccomp crisisST temp11 temp15
*roccomp crisisST temp11 temp15, gr


***************** AUXILIARY RESULTS *********************************



****  -- check interaction with investment growth

gen dll5invr=dll5*dlrinv5

**5 year moving average
logit crisisST dll5 dlrinv5 ccode*,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
outreg2 using TableAUX, replace tex nocons addstat( chicountry, `ccountry', pcountry, `pcountry', nobs, `nobs', pseudo-r2, `pseud', pseudo-l, `ll', chi2, `chi2logit', plogit, `plogit')  
		predict temp, xb
		roctab crisisST temp
		local area1 = r(area)
		local seroc = r(se)
outreg2 using TableAUX, append addstat(AUROC, `area1', seroc, `seroc')
drop temp

**interaction
logit crisisST dll5 dlrinv5 dll5invr ccode*,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
outreg2 using TableAUX, tex nocons addstat( chicountry, `ccountry', pcountry, `pcountry', nobs, `nobs', pseudo-r2, `pseud', pseudo-l, `ll', chi2, `chi2logit', plogit, `plogit')  
		predict temp, xb
		roctab crisisST temp
		local area1 = r(area)
		local seroc = r(se)
outreg2 using TableAUX, append addstat(AUROC, `area1', seroc, `seroc')
drop temp


**interaction pre 1945
logit crisisST dll5 dlrinv5 dll5invr ccode* if year<1945,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
outreg2 using TableAUX, tex nocons append addstat( chicountry, `ccountry', pcountry, `pcountry', nobs, `nobs', pseudo-r2, `pseud', pseudo-l, `ll', chi2, `chi2logit', plogit, `plogit')  
		predict temp, xb
		roctab crisisST temp if year<1945
		local area1 = r(area)
		local seroc = r(se)
outreg2 using TableAUX, append tex nocons addstat(AUROC, `area1', seroc, `seroc')
drop temp

**interaction post 1945
logit crisisST dll5 dlrinv5 dll5invr ccode* if year>1945,  vce(robust)
		   local nobs = e(N)
		   local pseud = e(r2_p)
		   local ll = e(ll)
		   local chi2logit = e(chi2)
		   local df = e(df_m)
		   local plogit = chi2tail(`df',`chi2logit')
		testparm ccode*
			local ccountry = r(chi2)
			local pcountry = r(p)
outreg2 using TableAUX, tex nocons append addstat( chicountry, `ccountry', pcountry, `pcountry', nobs, `nobs', pseudo-r2, `pseud', pseudo-l, `ll', chi2, `chi2logit', plogit, `plogit')  
		predict temp, xb
		roctab crisisST temp if year>1945
		local area1 = r(area)
		local seroc = r(se)
outreg2 using TableAUX, append tex nocons addstat(AUROC, `area1', seroc, `seroc')
drop temp


set more on
log close

